# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_text_generation_chat.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3model/model/v1alpha/task_text_generation_chat.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a model/model/v1alpha/common.proto\"\xa5\x04\n\x17TextGenerationChatInput\x12\x1c\n\x06prompt\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02R\x06prompt\x12K\n\rprompt_images\x18\x02 \x03(\x0b\x32 .model.model.v1alpha.PromptImageB\x04\xe2\x41\x01\x01R\x0cpromptImages\x12\x45\n\x0c\x63hat_history\x18\x03 \x03(\x0b\x32\x1c.model.model.v1alpha.MessageB\x04\xe2\x41\x01\x01R\x0b\x63hatHistory\x12\x30\n\x0esystem_message\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01H\x00R\rsystemMessage\x88\x01\x01\x12/\n\x0emax_new_tokens\x18\x05 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x01R\x0cmaxNewTokens\x88\x01\x01\x12+\n\x0btemperature\x18\x06 \x01(\x02\x42\x04\xe2\x41\x01\x01H\x02R\x0btemperature\x88\x01\x01\x12\x1e\n\x05top_k\x18\x07 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x03R\x04topK\x88\x01\x01\x12\x1d\n\x04seed\x18\x08 \x01(\x05\x42\x04\xe2\x41\x01\x01H\x04R\x04seed\x88\x01\x01\x12@\n\x0c\x65xtra_params\x18\t \x01(\x0b\x32\x17.google.protobuf.StructB\x04\xe2\x41\x01\x01R\x0b\x65xtraParamsB\x11\n\x0f_system_messageB\x11\n\x0f_max_new_tokensB\x0e\n\x0c_temperatureB\x08\n\x06_top_kB\x07\n\x05_seed\"4\n\x18TextGenerationChatOutput\x12\x18\n\x04text\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x04textB\xe8\x01\n\x17\x63om.model.model.v1alphaB\x1bTaskTextGenerationChatProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_text_generation_chat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\033TaskTextGenerationChatProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _TEXTGENERATIONCHATINPUT.fields_by_name['prompt']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['prompt']._serialized_options = b'\342A\001\002'
  _TEXTGENERATIONCHATINPUT.fields_by_name['prompt_images']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['prompt_images']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['chat_history']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['chat_history']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['system_message']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['system_message']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['max_new_tokens']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['max_new_tokens']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['temperature']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['temperature']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['top_k']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['top_k']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['seed']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['seed']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATINPUT.fields_by_name['extra_params']._options = None
  _TEXTGENERATIONCHATINPUT.fields_by_name['extra_params']._serialized_options = b'\342A\001\001'
  _TEXTGENERATIONCHATOUTPUT.fields_by_name['text']._options = None
  _TEXTGENERATIONCHATOUTPUT.fields_by_name['text']._serialized_options = b'\342A\001\003'
  _globals['_TEXTGENERATIONCHATINPUT']._serialized_start=174
  _globals['_TEXTGENERATIONCHATINPUT']._serialized_end=723
  _globals['_TEXTGENERATIONCHATOUTPUT']._serialized_start=725
  _globals['_TEXTGENERATIONCHATOUTPUT']._serialized_end=777
# @@protoc_insertion_point(module_scope)



from dataclasses import dataclass
from typing import List

from instill.helpers.protobufs.ray_pb2 import (
    ModelMetadataRequest,
    ModelMetadataResponse,
    RayServiceCallRequest,
    RayServiceCallResponse,
    InferTensor,
)

from instill.helpers.const import DataType


@dataclass
class Metadata:
    name: str
    datatype: str
    shape: list


def construct_metadata_response(
    req: ModelMetadataRequest,
    inputs: List[Metadata],
    outputs: List[Metadata],
) -> ModelMetadataResponse:
    resp = ModelMetadataResponse(
        name=req.name,
        versions=req.version,
        framework="python",
        inputs=[],
        outputs=[],
    )

    for i in inputs:
        resp.inputs.append(
            ModelMetadataResponse.TensorMetadata(
                name=i.name,
                datatype=i.datatype,
                shape=i.shape,
            )
        )

    for o in outputs:
        resp.outputs.append(
            ModelMetadataResponse.TensorMetadata(
                name=o.name,
                datatype=o.datatype,
                shape=o.shape,
            )
        )

    return resp


def construct_infer_response(
    req: RayServiceCallRequest,
    outputs: List[Metadata],
    raw_outputs: List[bytes],
) -> RayServiceCallResponse:
    resp = RayServiceCallResponse(
        model_name=req.model_name,
        model_version=req.model_version,
        outputs=[],
        raw_output_contents=[],
    )

    for o in outputs:
        resp.outputs.append(
            InferTensor(
                name=o.name,
                datatype=o.datatype,
                shape=o.shape,
            )
        )

    resp.raw_output_contents.extend(raw_outputs)

    return resp


def construct_text_generation_metadata_response(
    req: ModelMetadataRequest,
) -> ModelMetadataResponse:
    return construct_metadata_response(
        req=req,
        inputs=[
            Metadata(
                name="prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="prompt_images",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="chat_history",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="system_message",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="max_new_tokens",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="temperature",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[1],
            ),
            Metadata(
                name="top_k",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="random_seed",
                datatype=str(DataType.TYPE_UINT64.name),
                shape=[1],
            ),
            Metadata(
                name="extra_params",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
        ],
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[-1, -1],
            ),
        ],
    )


def construct_text_generation_infer_response(
    req: RayServiceCallRequest,
    shape: list,
    raw_outputs: List[bytes],
):
    return construct_infer_response(
        req=req,
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=shape,
            )
        ],
        raw_outputs=raw_outputs,
    )


def construct_text_generation_chat_metadata_response(
    req: ModelMetadataRequest,
) -> ModelMetadataResponse:
    return construct_metadata_response(
        req=req,
        inputs=[
            Metadata(
                name="prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="prompt_images",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="chat_history",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="system_message",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="max_new_tokens",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="temperature",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[1],
            ),
            Metadata(
                name="top_k",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="random_seed",
                datatype=str(DataType.TYPE_UINT64.name),
                shape=[1],
            ),
            Metadata(
                name="extra_params",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
        ],
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[-1, -1],
            ),
        ],
    )


def construct_text_generation_chat_infer_response(
    req: RayServiceCallRequest,
    shape: list,
    raw_outputs: List[bytes],
):
    return construct_infer_response(
        req=req,
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=shape,
            )
        ],
        raw_outputs=raw_outputs,
    )


def construct_text_to_image_metadata_response(
    req: ModelMetadataRequest,
):
    return construct_metadata_response(
        req=req,
        inputs=[
            Metadata(
                name="prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="negative_prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="prompt_image",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="samples",
                datatype=str(DataType.TYPE_INT32.name),
                shape=[1],
            ),
            Metadata(
                name="scheduler",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="steps",
                datatype=str(DataType.TYPE_INT32.name),
                shape=[1],
            ),
            Metadata(
                name="guidance_scale",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[1],
            ),
            Metadata(
                name="seed",
                datatype=str(DataType.TYPE_INT64.name),
                shape=[1],
            ),
            Metadata(
                name="extra_params",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
        ],
        outputs=[
            Metadata(
                name="images",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[-1, -1, -1, -1],
            ),
        ],
    )


def construct_text_to_image_infer_response(
    req: RayServiceCallRequest,
    shape: list,
    raw_outputs: List[bytes],
):
    return construct_infer_response(
        req=req,
        outputs=[
            Metadata(
                name="images",
                datatype=str(DataType.TYPE_FP32.name),
                shape=shape,
            )
        ],
        raw_outputs=raw_outputs,
    )


def construct_image_to_image_metadata_response(
    req: ModelMetadataRequest,
):
    return construct_metadata_response(
        req=req,
        inputs=[
            Metadata(
                name="prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="negative_prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="prompt_image",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="samples",
                datatype=str(DataType.TYPE_INT32.name),
                shape=[1],
            ),
            Metadata(
                name="scheduler",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="steps",
                datatype=str(DataType.TYPE_INT32.name),
                shape=[1],
            ),
            Metadata(
                name="guidance_scale",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[1],
            ),
            Metadata(
                name="seed",
                datatype=str(DataType.TYPE_INT64.name),
                shape=[1],
            ),
            Metadata(
                name="extra_params",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
        ],
        outputs=[
            Metadata(
                name="images",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[-1, -1, -1, -1],
            ),
        ],
    )


def construct_image_to_image_infer_response(
    req: RayServiceCallRequest,
    shape: list,
    raw_outputs: List[bytes],
):
    return construct_infer_response(
        req=req,
        outputs=[
            Metadata(
                name="images",
                datatype=str(DataType.TYPE_FP32.name),
                shape=shape,
            )
        ],
        raw_outputs=raw_outputs,
    )


def construct_visual_question_answering_metadata_response(
    req: ModelMetadataRequest,
):
    return construct_metadata_response(
        req=req,
        inputs=[
            Metadata(
                name="prompt",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="prompt_images",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="chat_history",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="system_message",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
            Metadata(
                name="max_new_tokens",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="temperature",
                datatype=str(DataType.TYPE_FP32.name),
                shape=[1],
            ),
            Metadata(
                name="top_k",
                datatype=str(DataType.TYPE_UINT32.name),
                shape=[1],
            ),
            Metadata(
                name="random_seed",
                datatype=str(DataType.TYPE_UINT64.name),
                shape=[1],
            ),
            Metadata(
                name="extra_params",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[1],
            ),
        ],
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=[-1, -1],
            ),
        ],
    )


def construct_visual_question_answering_infer_response(
    req: RayServiceCallRequest,
    shape: list,
    raw_outputs: List[bytes],
):
    return construct_infer_response(
        req=req,
        outputs=[
            Metadata(
                name="text",
                datatype=str(DataType.TYPE_STRING.name),
                shape=shape,
            )
        ],
        raw_outputs=raw_outputs,
    )



from typing import Union

import grpc

import instill.protogen.artifact.artifact.v1alpha.artifact_public_service_pb2_grpc as artifact_service
import instill.protogen.core.mgmt.v1beta.mgmt_public_service_pb2_grpc as mgmt_service
import instill.protogen.model.model.v1alpha.model_public_service_pb2_grpc as model_service
import instill.protogen.vdp.pipeline.v1beta.pipeline_public_service_pb2_grpc as pipeline_service

MB = 1024**2


class InstillInstance:
    def __init__(self, stub, url: str, token: str, secure: bool, async_enabled: bool):
        self.url: str = url
        self.token: str = token
        self.async_enabled: bool = async_enabled
        self.metadata: Union[str, tuple] = ""

        channel_options = (
            ("grpc.max_send_message_length", 32 * MB),
            ("grpc.max_receive_message_length", 32 * MB),
        )

        if not secure:
            channel = grpc.insecure_channel(url, options=channel_options)
            self.metadata = (
                (
                    "authorization",
                    f"Bearer {token}",
                ),
            )
            if async_enabled:
                async_channel = grpc.aio.insecure_channel(url, options=channel_options)
        else:
            ssl_creds = grpc.ssl_channel_credentials()
            call_creds = grpc.access_token_call_credentials(token)
            creds = grpc.composite_channel_credentials(ssl_creds, call_creds)
            channel = grpc.secure_channel(
                target=url, credentials=creds, options=channel_options
            )
            if async_enabled:
                async_channel = grpc.aio.secure_channel(
                    target=url, credentials=creds, options=channel_options
                )
        self.channel: grpc.Channel = channel
        self.client: Union[
            model_service.ModelPublicServiceStub,
            pipeline_service.PipelinePublicServiceStub,
            mgmt_service.MgmtPublicServiceStub,
            artifact_service.ArtifactPublicServiceStub,
        ] = stub(channel)
        if async_enabled:
            self.async_channel: grpc.Channel = async_channel
            self.async_client: Union[
                model_service.ModelPublicServiceStub,
                pipeline_service.PipelinePublicServiceStub,
                mgmt_service.MgmtPublicServiceStub,
                artifact_service.ArtifactPublicServiceStub,
            ] = stub(async_channel)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.mgmt.v1beta import mgmt_pb2 as core_dot_mgmt_dot_v1beta_dot_mgmt__pb2


class MgmtPrivateServiceStub(object):
    """Mgmt service responds to internal access
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListUsersAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/ListUsersAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.FromString,
                )
        self.GetUserAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetUserAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.FromString,
                )
        self.LookUpUserAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/LookUpUserAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.FromString,
                )
        self.ListOrganizationsAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/ListOrganizationsAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.FromString,
                )
        self.GetOrganizationAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.FromString,
                )
        self.LookUpOrganizationAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/LookUpOrganizationAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.FromString,
                )
        self.GetUserSubscriptionAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetUserSubscriptionAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.FromString,
                )
        self.GetOrganizationSubscriptionAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationSubscriptionAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.FromString,
                )
        self.SubtractCreditAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/SubtractCreditAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminResponse.FromString,
                )
        self.GetRemainingCreditAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/GetRemainingCreditAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminResponse.FromString,
                )
        self.CheckNamespaceAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/CheckNamespaceAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminResponse.FromString,
                )
        self.CheckNamespaceByUIDAdmin = channel.unary_unary(
                '/core.mgmt.v1beta.MgmtPrivateService/CheckNamespaceByUIDAdmin',
                request_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminRequest.SerializeToString,
                response_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminResponse.FromString,
                )


class MgmtPrivateServiceServicer(object):
    """Mgmt service responds to internal access
    """

    def ListUsersAdmin(self, request, context):
        """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
        a ListUsersAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserAdmin(self, request, context):
        """GetUserAdmin method receives a GetUserAdminRequest message and returns
        a GetUserAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpUserAdmin(self, request, context):
        """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
        returns a LookUpUserAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOrganizationsAdmin(self, request, context):
        """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
        a ListOrganizationsAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationAdmin(self, request, context):
        """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
        a GetOrganizationAdminResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LookUpOrganizationAdmin(self, request, context):
        """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
        returns a LookUpOrganizationAdminResponse
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUserSubscriptionAdmin(self, request, context):
        """GetUserSubscriptionAdmin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOrganizationSubscriptionAdmin(self, request, context):
        """GetOrganizationSubscriptionAdmin
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubtractCreditAdmin(self, request, context):
        """Subtract Instill Credit from a user or organization account.

        This endpoint subtracts the specified amount of Instill Credit from an
        account. This is intended for processes on Instill Cloud that consume
        credit, such as the execution of pre-configured connectors.
        Note that if the remaining credit in the account is less than the
        requested amount, it will be subtracted anyways, leaving the account
        credit at zero. A ResourceExhausted error will be returned in this case.

        On Instill Core, this endpoint will return an Unimplemented status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRemainingCreditAdmin(self, request, context):
        """Get the remaining Instill Credit by owner UID

        This endpoint fetches the remaining unexpired credit of a user or
        organization, referenced by UID.

        On Instill Core, this endpoint will return a 404 Not Found status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNamespaceAdmin(self, request, context):
        """Check if a namespace is in use

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckNamespaceByUIDAdmin(self, request, context):
        """Check if a namespace is in use by UID

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MgmtPrivateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListUsersAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUsersAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.SerializeToString,
            ),
            'GetUserAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.SerializeToString,
            ),
            'LookUpUserAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpUserAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.SerializeToString,
            ),
            'ListOrganizationsAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOrganizationsAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.SerializeToString,
            ),
            'GetOrganizationAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.SerializeToString,
            ),
            'LookUpOrganizationAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.LookUpOrganizationAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.SerializeToString,
            ),
            'GetUserSubscriptionAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUserSubscriptionAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.SerializeToString,
            ),
            'GetOrganizationSubscriptionAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOrganizationSubscriptionAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.SerializeToString,
            ),
            'SubtractCreditAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.SubtractCreditAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminResponse.SerializeToString,
            ),
            'GetRemainingCreditAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRemainingCreditAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminResponse.SerializeToString,
            ),
            'CheckNamespaceAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNamespaceAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminResponse.SerializeToString,
            ),
            'CheckNamespaceByUIDAdmin': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckNamespaceByUIDAdmin,
                    request_deserializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminRequest.FromString,
                    response_serializer=core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.mgmt.v1beta.MgmtPrivateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MgmtPrivateService(object):
    """Mgmt service responds to internal access
    """

    @staticmethod
    def ListUsersAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/ListUsersAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListUsersAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetUserAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpUserAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/LookUpUserAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpUserAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOrganizationsAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/ListOrganizationsAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.ListOrganizationsAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LookUpOrganizationAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/LookUpOrganizationAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.LookUpOrganizationAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetUserSubscriptionAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetUserSubscriptionAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetUserSubscriptionAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetOrganizationSubscriptionAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetOrganizationSubscriptionAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetOrganizationSubscriptionAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubtractCreditAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/SubtractCreditAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.SubtractCreditAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRemainingCreditAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/GetRemainingCreditAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.GetRemainingCreditAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNamespaceAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/CheckNamespaceAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckNamespaceByUIDAdmin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.mgmt.v1beta.MgmtPrivateService/CheckNamespaceByUIDAdmin',
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminRequest.SerializeToString,
            core_dot_mgmt_dot_v1beta_dot_mgmt__pb2.CheckNamespaceByUIDAdminResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from core.usage.v1beta import usage_pb2 as core_dot_usage_dot_v1beta_dot_usage__pb2


class UsageServiceStub(object):
    """UsageService responds to incoming usage requests.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Liveness = channel.unary_unary(
                '/core.usage.v1beta.UsageService/Liveness',
                request_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessRequest.SerializeToString,
                response_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessResponse.FromString,
                )
        self.Readiness = channel.unary_unary(
                '/core.usage.v1beta.UsageService/Readiness',
                request_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessRequest.SerializeToString,
                response_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessResponse.FromString,
                )
        self.CreateSession = channel.unary_unary(
                '/core.usage.v1beta.UsageService/CreateSession',
                request_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionRequest.SerializeToString,
                response_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionResponse.FromString,
                )
        self.SendSessionReport = channel.unary_unary(
                '/core.usage.v1beta.UsageService/SendSessionReport',
                request_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportRequest.SerializeToString,
                response_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportResponse.FromString,
                )


class UsageServiceServicer(object):
    """UsageService responds to incoming usage requests.
    """

    def Liveness(self, request, context):
        """Liveness method receives a LivenessRequest message and returns a
        LivenessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Readiness(self, request, context):
        """Readiness method receives a ReadinessRequest message and returns a
        ReadinessResponse message.
        See https://github.com/grpc/grpc/blob/master/doc/health-checking.md
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateSession(self, request, context):
        """CreateSession method receives a CreateSessionRequest message and returns
        a CreateSessionResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendSessionReport(self, request, context):
        """SendSessionReport method receives a SendSessionReportRequest message and
        returns a SendSessionReportResponse message.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UsageServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Liveness': grpc.unary_unary_rpc_method_handler(
                    servicer.Liveness,
                    request_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessRequest.FromString,
                    response_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessResponse.SerializeToString,
            ),
            'Readiness': grpc.unary_unary_rpc_method_handler(
                    servicer.Readiness,
                    request_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessRequest.FromString,
                    response_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessResponse.SerializeToString,
            ),
            'CreateSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSession,
                    request_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionRequest.FromString,
                    response_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionResponse.SerializeToString,
            ),
            'SendSessionReport': grpc.unary_unary_rpc_method_handler(
                    servicer.SendSessionReport,
                    request_deserializer=core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportRequest.FromString,
                    response_serializer=core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'core.usage.v1beta.UsageService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UsageService(object):
    """UsageService responds to incoming usage requests.
    """

    @staticmethod
    def Liveness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.usage.v1beta.UsageService/Liveness',
            core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessRequest.SerializeToString,
            core_dot_usage_dot_v1beta_dot_usage__pb2.LivenessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Readiness(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.usage.v1beta.UsageService/Readiness',
            core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessRequest.SerializeToString,
            core_dot_usage_dot_v1beta_dot_usage__pb2.ReadinessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.usage.v1beta.UsageService/CreateSession',
            core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionRequest.SerializeToString,
            core_dot_usage_dot_v1beta_dot_usage__pb2.CreateSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendSessionReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/core.usage.v1beta.UsageService/SendSessionReport',
            core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportRequest.SerializeToString,
            core_dot_usage_dot_v1beta_dot_usage__pb2.SendSessionReportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model/model/v1alpha/task_keypoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from model.model.v1alpha import common_pb2 as model_dot_model_dot_v1alpha_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'model/model/v1alpha/task_keypoint.proto\x12\x13model.model.v1alpha\x1a\x1fgoogle/api/field_behavior.proto\x1a model/model/v1alpha/common.proto\"F\n\x08Keypoint\x12\x12\n\x01x\x18\x01 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01x\x12\x12\n\x01y\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01y\x12\x12\n\x01v\x18\x03 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x01v\"\xba\x01\n\x0eKeypointObject\x12\x41\n\tkeypoints\x18\x01 \x03(\x0b\x32\x1d.model.model.v1alpha.KeypointB\x04\xe2\x41\x01\x03R\tkeypoints\x12\x1a\n\x05score\x18\x02 \x01(\x02\x42\x04\xe2\x41\x01\x03R\x05score\x12I\n\x0c\x62ounding_box\x18\x03 \x01(\x0b\x32 .model.model.v1alpha.BoundingBoxB\x04\xe2\x41\x01\x03R\x0b\x62oundingBox\"[\n\rKeypointInput\x12\x1d\n\timage_url\x18\x01 \x01(\tH\x00R\x08imageUrl\x12#\n\x0cimage_base64\x18\x02 \x01(\tH\x00R\x0bimageBase64B\x06\n\x04type\"^\n\x13KeypointInputStream\x12\'\n\x0c\x66ile_lengths\x18\x01 \x03(\rB\x04\xe2\x41\x01\x02R\x0b\x66ileLengths\x12\x1e\n\x07\x63ontent\x18\x02 \x01(\x0c\x42\x04\xe2\x41\x01\x02R\x07\x63ontent\"U\n\x0eKeypointOutput\x12\x43\n\x07objects\x18\x01 \x03(\x0b\x32#.model.model.v1alpha.KeypointObjectB\x04\xe2\x41\x01\x03R\x07objectsB\xde\x01\n\x17\x63om.model.model.v1alphaB\x11TaskKeypointProtoP\x01ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\xa2\x02\x03MMX\xaa\x02\x13Model.Model.V1alpha\xca\x02\x13Model\\Model\\V1alpha\xe2\x02\x1fModel\\Model\\V1alpha\\GPBMetadata\xea\x02\x15Model::Model::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model.model.v1alpha.task_keypoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.model.model.v1alphaB\021TaskKeypointProtoP\001ZBgithub.com/instill-ai/protogen-go/model/model/v1alpha;modelv1alpha\242\002\003MMX\252\002\023Model.Model.V1alpha\312\002\023Model\\Model\\V1alpha\342\002\037Model\\Model\\V1alpha\\GPBMetadata\352\002\025Model::Model::V1alpha'
  _KEYPOINT.fields_by_name['x']._options = None
  _KEYPOINT.fields_by_name['x']._serialized_options = b'\342A\001\003'
  _KEYPOINT.fields_by_name['y']._options = None
  _KEYPOINT.fields_by_name['y']._serialized_options = b'\342A\001\003'
  _KEYPOINT.fields_by_name['v']._options = None
  _KEYPOINT.fields_by_name['v']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['keypoints']._options = None
  _KEYPOINTOBJECT.fields_by_name['keypoints']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['score']._options = None
  _KEYPOINTOBJECT.fields_by_name['score']._serialized_options = b'\342A\001\003'
  _KEYPOINTOBJECT.fields_by_name['bounding_box']._options = None
  _KEYPOINTOBJECT.fields_by_name['bounding_box']._serialized_options = b'\342A\001\003'
  _KEYPOINTINPUTSTREAM.fields_by_name['file_lengths']._options = None
  _KEYPOINTINPUTSTREAM.fields_by_name['file_lengths']._serialized_options = b'\342A\001\002'
  _KEYPOINTINPUTSTREAM.fields_by_name['content']._options = None
  _KEYPOINTINPUTSTREAM.fields_by_name['content']._serialized_options = b'\342A\001\002'
  _KEYPOINTOUTPUT.fields_by_name['objects']._options = None
  _KEYPOINTOUTPUT.fields_by_name['objects']._serialized_options = b'\342A\001\003'
  _globals['_KEYPOINT']._serialized_start=131
  _globals['_KEYPOINT']._serialized_end=201
  _globals['_KEYPOINTOBJECT']._serialized_start=204
  _globals['_KEYPOINTOBJECT']._serialized_end=390
  _globals['_KEYPOINTINPUT']._serialized_start=392
  _globals['_KEYPOINTINPUT']._serialized_end=483
  _globals['_KEYPOINTINPUTSTREAM']._serialized_start=485
  _globals['_KEYPOINTINPUTSTREAM']._serialized_end=579
  _globals['_KEYPOINTOUTPUT']._serialized_start=581
  _globals['_KEYPOINTOUTPUT']._serialized_end=666
# @@protoc_insertion_point(module_scope)



# type: ignore
from instill.helpers import (
    construct_text_generation_chat_infer_response,
    construct_text_generation_chat_metadata_response,
)
from instill.helpers.const import TextGenerationChatInput
from instill.helpers.ray_config import InstillDeployable, instill_deployment
from instill.helpers.ray_io import StandardTaskIO


@instill_deployment
class Phimini:
    """Custom model implementation"""

    def __init__(self):
        """Load model into memory"""
        # model = AutoModelForCausalLM.from_pretrained(
        #     "microsoft/Phi-3-mini-4k-instruct",
        #     device_map="cuda",
        #     torch_dtype="auto",
        #     trust_remote_code=True,
        # )
        # tokenizer = AutoTokenizer.from_pretrained("microsoft/Phi-3-mini-4k-instruct")

        # self.pipeline = pipeline(
        #     "text-generation",
        #     model=model,
        #     tokenizer=tokenizer,
        # )

    def ModelMetadata(self, req):
        """Define model input and output shape base on task type"""
        # return construct_text_generation_chat_metadata_response(req=req)

    async def __call__(self, request):
        """Run inference logic"""

        # deserialize input base on task type
        # task_text_generation_chat_input: TextGenerationChatInput = (
        #     StandardTaskIO.parse_task_text_generation_chat_input(request=request)
        # )

        # preprocess
        # conv = [
        #     {
        #         "role": "system",
        #         "content": task_text_generation_chat_input.system_message,
        #     },
        #     {
        #         "role": "user",
        #         "content": task_text_generation_chat_input.prompt,
        #     },
        # ]
        # generation_args = {
        #     "max_new_tokens": task_text_generation_chat_input.max_new_tokens,
        #     "return_full_text": False,
        #     "temperature": task_text_generation_chat_input.temperature,
        #     "top_k": task_text_generation_chat_input.top_k,
        #     "top_p": 0.95,
        #     "do_sample": False,
        # }

        # inference
        # sequences = self.pipeline(conv, **generation_args)

        # convert the model output into response output using StandardTaskIO
        # task_text_generation_chat_output = (
        #     StandardTaskIO.parse_task_text_generation_chat_output(sequences=sequences)
        # )

        # return response
        # return construct_text_generation_chat_infer_response(
        #     req=request,
        #     # specify the output dimension
        #     shape=[1, len(sequences)],
        #     raw_outputs=[task_text_generation_chat_output],
        # )


# define model deployment entrypoint
entrypoint = InstillDeployable(Phimini).get_deployment_handle()
